@@ -16,7 +16,7 @@ Q_OBJECT
 
 protected:  // Methods
 // Constructor
-MTestWindow( MTestModel* aModel );
+MTestWindow( MTestModel* aModel, QWidget* parent = 0, Qt::WindowFlags flags = 0 );
 // From QWidget
 void closeEvent( QCloseEvent* event );
 
