@@ -194,7 +194,7 @@ AddDictTab( dict );
 void TMainWindow::Load()
 {
 QString filePath = QFileDialog::getOpenFileName( this, tr("Load dictionary"), iWorkPath,
-                                                 tr("Dictionaries (*.fmd);;All files (*)") );
+                                                 tr("Dictionaries (*.fmd);;All files (*.*)") );
 if( filePath.isEmpty() )
     return;
 iWorkPath = QFileInfo( filePath ).path();
@@ -285,7 +285,7 @@ QString filePath = dict->FilePath();
 if( filePath.isEmpty() )
     filePath = iWorkPath + "/" + TDictionary::KNoName;
 filePath = QFileDialog::getSaveFileName(this, tr("Save dictionary as ..."), filePath,
-                                        tr("Dictionaries (*.fmd);;All files (*)"));
+                                        tr("Dictionaries (*.fmd);;All files (*.*)"));
 if( filePath.isEmpty() )
     return false;
 iWorkPath = QFileInfo( filePath ).path();
@@ -306,7 +306,7 @@ SaveAs( false );    // Do not change the file name
 void TMainWindow::Import()
 {
 QString filePath = QFileDialog::getOpenFileName(this, tr("Import CSV file"), iWorkPath,
-                                                tr("CSV files (*.csv *.txt);;All files (*)"));
+                                                tr("CSV files (*.csv *.txt);;All files (*.*)"));
 if( filePath.isEmpty() )
     return;
 iWorkPath = QFileInfo( filePath ).path();
@@ -330,7 +330,7 @@ if( exportDialog.exec() )
     if( dictFilePath.isEmpty() )
         dictFilePath = iWorkPath + "/" + TDictionary::KNoName;
     QString filePath = QFileDialog::getSaveFileName( this, tr("Export to CSV file"), dictFilePath + ".txt",
-                                                     tr("CSV files (*.csv *.txt);;All files (*)") );
+                                                     tr("CSV files (*.csv *.txt);;All files (*.*)") );
     if( filePath.isEmpty() )
         return;
     iWorkPath = QFileInfo( filePath ).path();
